/**
 * Anthropic provider implementation
 */
import Anthropic from '@anthropic-ai/sdk';
/**
 * Anthropic provider implementation
 */
export class AnthropicProvider {
    name = 'anthropic';
    provider = 'anthropic.messages';
    model;
    client;
    apiKey;
    baseUrl;
    constructor(model, options = {}) {
        this.model = model;
        this.apiKey = options.apiKey || process.env.ANTHROPIC_API_KEY || '';
        this.baseUrl = options.baseUrl;
        if (!this.apiKey) {
            throw new Error('Anthropic API key is required');
        }
        // Initialize Anthropic client
        this.client = new Anthropic({
            apiKey: this.apiKey,
            ...(this.baseUrl && { baseURL: this.baseUrl }),
        });
    }
    /**
     * Generate text using Anthropic API
     */
    async generateText(options) {
        const { messages, functions, temperature = 0.7, maxTokens, stopSequences, topP, } = options;
        // Extract system message
        const systemMessage = messages.find((msg) => msg.role === 'system');
        const nonSystemMessages = messages.filter((msg) => msg.role !== 'system');
        const formattedMessages = this.formatMessages(nonSystemMessages);
        try {
            const requestOptions = {
                model: this.model,
                messages: formattedMessages,
                temperature,
                max_tokens: maxTokens || 1024,
                ...(stopSequences && { stop_sequences: stopSequences }),
                ...(topP && { top_p: topP }),
                ...(systemMessage && { system: systemMessage.content }),
            };
            // Add tools if provided
            if (functions && functions.length > 0) {
                const tools = functions.map((fn) => ({
                    name: fn.name,
                    description: fn.description,
                    input_schema: fn.parameters,
                }));
                requestOptions.tools = tools;
            }
            const response = await this.client.messages.create(requestOptions);
            // Extract content and tool calls
            const content = response.content.find((c) => c.type === 'text')?.text || '';
            const toolCalls = response.content
                .filter((c) => {
                const contentType = c.type;
                return contentType === 'tool_use';
            })
                .map((c) => {
                const toolUse = c;
                return {
                    id: toolUse.id ||
                        `tool-${Math.random().toString(36).substring(2, 11)}`,
                    name: toolUse.name,
                    content: JSON.stringify(toolUse.input),
                };
            });
            return {
                text: content,
                toolCalls: toolCalls,
            };
        }
        catch (error) {
            throw new Error(`Error calling Anthropic API: ${error.message}`);
        }
    }
    /**
     * Count tokens in a text using Anthropic's tokenizer
     * Note: This is a simplified implementation
     */
    async countTokens(text) {
        // In a real implementation, you would use Anthropic's tokenizer
        // This is a simplified approximation
        return Math.ceil(text.length / 3.5);
    }
    /**
     * Format messages for Anthropic API
     */
    formatMessages(messages) {
        // Format messages for Anthropic API
        return messages.map((msg) => {
            if (msg.role === 'user') {
                return {
                    role: 'user',
                    content: msg.content,
                };
            }
            else if (msg.role === 'assistant') {
                return {
                    role: 'assistant',
                    content: msg.content,
                };
            }
            else if (msg.role === 'tool_result') {
                // Anthropic expects tool responses as an assistant message with tool_results
                return {
                    role: 'user',
                    content: [
                        {
                            type: 'tool_result',
                            tool_use_id: msg.tool_use_id, // Use name as the tool_use_id
                            content: msg.content,
                            is_error: msg.is_error,
                        },
                    ],
                };
            }
            else if (msg.role === 'tool_use') {
                return {
                    role: 'assistant',
                    content: [
                        {
                            type: 'tool_use',
                            name: msg.name,
                            id: msg.id,
                            input: JSON.parse(msg.content),
                        },
                    ],
                };
            }
            return {
                role: 'user',
                content: msg.content,
            };
        });
    }
}
//# sourceMappingURL=anthropic.js.map